@@ -10,10 +10,10 @@
     :license: MIT, see LICENSE for more details.
 """
 
-__version__ = '1.5.5'
+__version__ = '1.6.0'
 
 from .core import Social
 from .datastore import SQLAlchemyConnectionDatastore, \
-     MongoEngineConnectionDatastore
+     MongoEngineConnectionDatastore, PeeweeConnectionDatastore
 from .signals import connection_created, connection_failed, login_failed, \
      connection_removed, login_completed
